==> pointpos_api-0.2.0.tar.gz: test/ingredient_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Ingredient
void main() {
  var instance = new Ingredient();

  group('test Ingredient', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num unitId (default value: null)
    test('to test the property `unitId`', () async {
      // TODO
    });

    // num ingredientCategoryId (default value: null)
    test('to test the property `ingredientCategoryId`', () async {
      // TODO
    });

    // IngredientInventory inventory (default value: null)
    test('to test the property `inventory`', () async {
      // TODO
    });

    // IngredientCostOfGoodsSold costOfGoodsSold (default value: null)
    test('to test the property `costOfGoodsSold`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: null)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}

==> pointpos_api-0.2.1.tar.gz: test/ingredient_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';

// tests for Ingredient
void main() {
  var instance = new Ingredient();

  group('test Ingredient', () {
    // String id (default value: null)
    test('to test the property `id`', () async {
      // TODO
    });

    // String name (default value: null)
    test('to test the property `name`', () async {
      // TODO
    });

    // num unitId (default value: null)
    test('to test the property `unitId`', () async {
      // TODO
    });

    // num ingredientCategoryId (default value: null)
    test('to test the property `ingredientCategoryId`', () async {
      // TODO
    });

    // IngredientInventory inventory (default value: null)
    test('to test the property `inventory`', () async {
      // TODO
    });

    // IngredientCostOfGoodsSold costOfGoodsSold (default value: null)
    test('to test the property `costOfGoodsSold`', () async {
      // TODO
    });

    // DateTime createdAt (default value: null)
    test('to test the property `createdAt`', () async {
      // TODO
    });

    // String createdBy (default value: null)
    test('to test the property `createdBy`', () async {
      // TODO
    });

    // DateTime updatedAt (default value: null)
    test('to test the property `updatedAt`', () async {
      // TODO
    });

    // String updatedBy (default value: null)
    test('to test the property `updatedBy`', () async {
      // TODO
    });

    // bool deleted (default value: false)
    test('to test the property `deleted`', () async {
      // TODO
    });


  });

}
